Class: Headers
Overview
an object of this class represents the headers of a news-article
Constant Summary collapse
- @@config =
class-level configuration object
Configuration.instance
- @@log =
class-level logger as configured.
init_logger(@@config.log_target, @@config.log_level)
Instance Attribute Summary collapse
-
#lines ⇒ Object
readonly
Returns the value of attribute lines.
-
#newsgroups ⇒ Object
readonly
Returns the value of attribute newsgroups.
Instance Method Summary collapse
-
#header(name) ⇒ Object
returns the value of header ‘name’.
-
#initialize(article_text) ⇒ Headers
constructor
read the headers from the article.
-
#join ⇒ Object
return the headers as a String.
-
#method_missing(method, args = nil) ⇒ Object
basically a replacement for header(name), above.
-
#parameters ⇒ Object
would return the parameters, if there where any.
-
#remove(name) ⇒ Object
remove a header.
-
#update(article_text) ⇒ Object
Modify headers, if need be.
Methods included from Logging
init_logger, log_level=, log_target=
Constructor Details
#initialize(article_text) ⇒ Headers
read the headers from the article
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/headers.rb', line 39 def initialize(article_text) @log = @@log line = nil # transform the article to an array. line_array = article_text.split($LN) # find the first empty line end_index = line_array.index('') # keep the preceding lines. @lines = line_array.slice!(0, end_index) @log.debug('headers: ' << @lines.to_s) # headername: headervalue @headers = {} # fill the headers Hash from the header-lines. @lines.each do |l| h = l.split(':') @headers[h[0].strip.to_sym] = h[1...h.size].join(':').strip end @log.debug('headers are ' << @headers.to_s) # unused --------------> @parameters = nil @parameters = Parameters.new(header(:PPParam)) if header(:PPParam) remove(:PPParam) # <------------ unused, and the next condition cannot be met. unless @@config.skip_pp # ... Meaning: This statement is *always* executed @newsgroups = Newsgroups.new(header(:Newsgroups)) end end |
Dynamic Method Handling
This class handles dynamic methods through the method_missing method
#method_missing(method, args = nil) ⇒ Object
basically a replacement for header(name), above. But you can call self.Newsgroups or self.From etc.
119 120 121 122 |
# File 'lib/headers.rb', line 119 def method_missing(method, args = nil) return @headers[method] if @headers[method] @log.error("unknown symbol '#{method}'") end |
Instance Attribute Details
#lines ⇒ Object (readonly)
Returns the value of attribute lines.
132 133 134 |
# File 'lib/headers.rb', line 132 def lines @lines end |
#newsgroups ⇒ Object (readonly)
Returns the value of attribute newsgroups.
132 133 134 |
# File 'lib/headers.rb', line 132 def newsgroups @newsgroups end |
Instance Method Details
#header(name) ⇒ Object
returns the value of header ‘name’
73 74 75 76 77 78 79 80 81 |
# File 'lib/headers.rb', line 73 def header(name) # name must be a symbol. if name.respond_to?(:to_sym) @headers[name] else @log.error(name.to_s << ' is not a symbol!') nil end end |
#join ⇒ Object
return the headers as a String.
125 126 127 128 129 130 |
# File 'lib/headers.rb', line 125 def join htext = '' @headers.each_pair {|h, t| htext << h.to_s << ': ' << t << $LN } @log.debug('joined headers: ' << htext) htext end |
#parameters ⇒ Object
would return the parameters, if there where any.
108 109 110 |
# File 'lib/headers.rb', line 108 def parameters @parameters.params if @params end |
#remove(name) ⇒ Object
remove a header
113 114 115 |
# File 'lib/headers.rb', line 113 def remove(name) @headers.delete(name) if @headers[name] end |
#update(article_text) ⇒ Object
Modify headers, if need be. As parameters are not working, some of the conditions can be ignored.
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/headers.rb', line 86 def update(article_text) # condition does not trigger. if !@@config.no_xnay # statement is *always* executed @headers.merge( @newsgroups.xnay) if @newsgroups.xnay end # ... and so on. if !@@config.no_custom_headers ch = @@config.CUSTOM_HEADERS @log.debug('setting custom headers : ' << ch.inspect) if @@config.CUSTOM_HEADERS @@config.CUSTOM_HEADERS.each do |pair| ch = pair.split(':') @headers[ch[0].strip ] = ch[1].strip @headers.compact! end end end end |